==> cloudfront-1.60.0-sources.jar: software/amazon/awscdk/services/cloudfront/SSLMethod.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * The SSL method CloudFront will use for your distribution.
 * <p>
 * Server Name Indication (SNI) - is an extension to the TLS computer networking protocol by which a client indicates
 * which hostname it is attempting to connect to at the start of the handshaking process. This allows a server to present
 * multiple certificates on the same IP address and TCP port number and hence allows multiple secure (HTTPS) websites
 * (or any other service over TLS) to be served by the same IP address without requiring all those sites to use the same certificate.
 * <p>
 * CloudFront can use SNI to host multiple distributions on the same IP - which a large majority of clients will support.
 * <p>
 * If your clients cannot support SNI however - CloudFront can use dedicated IPs for your distribution - but there is a prorated monthly charge for
 * using this feature. By default, we use SNI - but you can optionally enable dedicated IPs (VIP).
 * <p>
 * See the CloudFront SSL for more details about pricing : https://aws.amazon.com/cloudfront/custom-ssl-domains/
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.536Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.SSLMethod")
public enum SSLMethod {
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    SNI,
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    VIP,
}

==> cloudfront-1.93.0-sources.jar: software/amazon/awscdk/services/cloudfront/SSLMethod.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * The SSL method CloudFront will use for your distribution.
 * <p>
 * Server Name Indication (SNI) - is an extension to the TLS computer networking protocol by which a client indicates
 * which hostname it is attempting to connect to at the start of the handshaking process. This allows a server to present
 * multiple certificates on the same IP address and TCP port number and hence allows multiple secure (HTTPS) websites
 * (or any other service over TLS) to be served by the same IP address without requiring all those sites to use the same certificate.
 * <p>
 * CloudFront can use SNI to host multiple distributions on the same IP - which a large majority of clients will support.
 * <p>
 * If your clients cannot support SNI however - CloudFront can use dedicated IPs for your distribution - but there is a prorated monthly charge for
 * using this feature. By default, we use SNI - but you can optionally enable dedicated IPs (VIP).
 * <p>
 * See the CloudFront SSL for more details about pricing : https://aws.amazon.com/cloudfront/custom-ssl-domains/
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.432Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.SSLMethod")
public enum SSLMethod {
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    SNI,
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VIP,
}
